@@ -87,6 +87,8 @@ class Node:
             if ut.check_if_subject_is_in_graph(self._graph,self._subject):
                 self._graph=ut.get_subject_graph(self._graph,self._subject)
                 self.get_metadata_from_graph(self._graph,self._subject) 
+            elif 'session' in str(type(self)):
+                pass
             else:
                 raise ValueError( 'Subject not in graph')
         self.__dict__.update(kwargs)
