@@ -50,12 +50,11 @@ class SessionNode(GeometryNode):
         Args:
             0.graph (Graph, optional): Upon initialisation, bigger graphs can be submitted and parsed i.e.: \n
                 > The RDF Graph of only the sessionNode (1 subject)
-                > AN RDF 
-            #1.sessionGraph (Graph, optional): The RDF Graph of all the nodes in the session. If a session node is present, it will be stored in self.graph (only 1 sessionNode is assumed). \n
-            2.graphPath (str, optional): The path of the Graph of only the session. \n
-            3.subject (URIRef, optional): The subject to parse the Graph with. \n
-            4.resources (Any, optional): A set of resources which will be converted to LinkedNodes \n
-            5.LinkedNodes (Nodes, optional): A set of Nodes (ImageNodes, MeshNodes) to contain within the session \n
+                > AN RDF Graph with only resourceNodes
+            1.graphPath (str, optional): The path of the Graph of only the session. \n
+            2.subject (URIRef, optional): The subject to parse the Graph with. \n
+            3.resources (Any, optional): A set of resources which will be converted to LinkedNodes \n
+            4.LinkedNodes (Nodes, optional): A set of Nodes (ImageNodes, MeshNodes) to contain within the session \n
             
             getResource (bool, optional= False): If True, the node will search for its physical resource on drive \n
             getMetaData (bool, optional= True): If True, the node will attempt to extract geometric metadata from the resource if present (cartesianBounds, etc.) \n
@@ -130,9 +129,7 @@ class SessionNode(GeometryNode):
         if not list :
             return []
         elif all('Node' in str(type(value)) for value in list):
-            for node in list:
-                if node not in self._linkedNodes:
-                    self._linkedNodes.append(node)
+            self.add_linked_nodes(list)
         else:
             raise ValueError('Some elements in self.linkedNodes are not Nodes')    
     
@@ -140,7 +137,7 @@ class SessionNode(GeometryNode):
     @property
     def linkedSubjects(self): 
         """Get the linkedSubjects (URIRef) of the node."""
-        if self._linkedSubjects is None:
+        if not self._linkedSubjects:
            self._linkedSubjects= [node.subject for node in self.linkedNodes]
         return self._linkedSubjects
 
